==> 4.7.4.tar.gz: terraform-provider-decort/internal/service/cloudbroker/kvmvm/utility_compute_list_deleted.go <==
/*
Copyright (c) 2019-2023 Digital Energy Cloud Solutions LLC. All Rights Reserved.
Authors:
Petr Krutov, <petr.krutov@digitalenergy.online>
Stanislav Solovev, <spsolovev@digitalenergy.online>
Kasim Baybikov, <kmbaybikov@basistech.ru>

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

/*
Terraform DECORT provider - manage resources provided by DECORT (Digital Energy Cloud
Orchestration Technology) with Terraform by Hashicorp.

Source code: https://repository.basistech.ru/BASIS/terraform-provider-decort

Please see README.md to learn where to place source code so that it
builds seamlessly.

Documentation: https://repository.basistech.ru/BASIS/terraform-provider-decort/wiki
*/

package kvmvm

import (
	"context"

	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/schema"
	"repository.basistech.ru/BASIS/decort-golang-sdk/pkg/cloudbroker/compute"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/controller"
)

func utilityDataComputeListDeletedCheckPresence(ctx context.Context, d *schema.ResourceData, m interface{}) (*compute.ListComputes, error) {
	c := m.(*controller.ControllerCfg)
	req := compute.ListDeletedRequest{}

	if byId, ok := d.GetOk("by_id"); ok {
		req.ByID = uint64(byId.(int))
	}
	if name, ok := d.GetOk("name"); ok {
		req.Name = name.(string)
	}
	if accountId, ok := d.GetOk("account_id"); ok {
		req.AccountID = uint64(accountId.(int))
	}
	if rgName, ok := d.GetOk("rg_name"); ok {
		req.RGName = rgName.(string)
	}
	if rgId, ok := d.GetOk("rg_id"); ok {
		req.RGID = uint64(rgId.(int))
	}
	if techStatus, ok := d.GetOk("tech_status"); ok {
		req.TechStatus = techStatus.(string)
	}
	if ipAddress, ok := d.GetOk("ip_address"); ok {
		req.IPAddress = ipAddress.(string)
	}
	if extNetName, ok := d.GetOk("extnet_name"); ok {
		req.ExtNetName = extNetName.(string)
	}
	if extnetId, ok := d.GetOk("extnet_id"); ok {
		req.ExtNetID = uint64(extnetId.(int))
	}
	if sortBy, ok := d.GetOk("sort_by"); ok {
		req.SortBy = sortBy.(string)
	}
	if page, ok := d.GetOk("page"); ok {
		req.Page = uint64(page.(int))
	}
	if size, ok := d.GetOk("size"); ok {
		req.Size = uint64(size.(int))
	}

	listComputes, err := c.CloudBroker().Compute().ListDeleted(ctx, req)
	if err != nil {
		return nil, err
	}

	return listComputes, nil
}

==> 4.9.0.tar.gz: terraform-provider-decort/internal/service/cloudbroker/kvmvm/utility_compute_list_deleted.go <==
/*
Copyright (c) 2019-2023 Digital Energy Cloud Solutions LLC. All Rights Reserved.
Authors:
Petr Krutov, <petr.krutov@digitalenergy.online>
Stanislav Solovev, <spsolovev@digitalenergy.online>
Kasim Baybikov, <kmbaybikov@basistech.ru>

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

/*
Terraform DECORT provider - manage resources provided by DECORT (Digital Energy Cloud
Orchestration Technology) with Terraform by Hashicorp.

Source code: https://repository.basistech.ru/BASIS/terraform-provider-decort

Please see README.md to learn where to place source code so that it
builds seamlessly.

Documentation: https://repository.basistech.ru/BASIS/terraform-provider-decort/wiki
*/

package kvmvm

import (
	"context"
	"regexp"

	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/schema"
	"repository.basistech.ru/BASIS/decort-golang-sdk/pkg/cloudbroker/compute"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/controller"
)

func utilityDataComputeListDeletedCheckPresence(ctx context.Context, d *schema.ResourceData, m interface{}) (*compute.ListDeletedComputes, error) {
	c := m.(*controller.ControllerCfg)
	req := compute.ListDeletedRequest{}

	if byId, ok := d.GetOk("by_id"); ok {
		req.ByID = uint64(byId.(int))
	}
	if name, ok := d.GetOk("name"); ok {
		req.Name = name.(string)
	}
	if accountId, ok := d.GetOk("account_id"); ok {
		req.AccountID = uint64(accountId.(int))
	}
	if rgName, ok := d.GetOk("rg_name"); ok {
		req.RGName = rgName.(string)
	}
	if rgId, ok := d.GetOk("rg_id"); ok {
		req.RGID = uint64(rgId.(int))
	}
	if techStatus, ok := d.GetOk("tech_status"); ok {
		req.TechStatus = techStatus.(string)
	}
	if ipAddress, ok := d.GetOk("ip_address"); ok {
		req.IPAddress = ipAddress.(string)
	}
	if extNetName, ok := d.GetOk("extnet_name"); ok {
		req.ExtNetName = extNetName.(string)
	}
	if extnetId, ok := d.GetOk("extnet_id"); ok {
		req.ExtNetID = uint64(extnetId.(int))
	}
	if sortBy, ok := d.GetOk("sort_by"); ok {
		req.SortBy = sortBy.(string)
	}
	if page, ok := d.GetOk("page"); ok {
		req.Page = uint64(page.(int))
	}
	if size, ok := d.GetOk("size"); ok {
		req.Size = uint64(size.(int))
	}

	listComputes, err := c.CloudBroker().Compute().ListDeleted(ctx, req)
	if err != nil {
		return nil, err
	}

	return listComputes, nil
}
func matchDeletedComputes(computeList *compute.ListDeletedComputes) *compute.ListDeletedComputes {
	matched, _ := regexp.Compile(`[a-zA-Z]+\\d+-[a-zA-Z]+\\d+-[a-zA-Z]+\\d+`)
	result := computeList.FilterFunc(func(ic compute.ItemDeletedCompute) bool {
		res := matched.Match([]byte(ic.Name))
		return !res
	})

	return &result
}
